@@ -1,14 +1,14 @@
 from dissect.hypervisor.backup import vma, wim, xva
+from dissect.hypervisor.descriptor import hyperv, ovf, vbox, vmx
 from dissect.hypervisor.disk import qcow2, vdi, vhd, vhdx, vmdk
-from dissect.hypervisor.descriptor import hyperv, ovf, vmx
 from dissect.hypervisor.util import envelope, vmtar
 
-
 __all__ = [
     "envelope",
     "hyperv",
     "ovf",
     "qcow2",
+    "vbox",
     "vdi",
     "vhd",
     "vhdx",
